package ac.ed.lurg.types;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import ac.ed.lurg.ModelConfig;

public enum CommodityType {

	CEREALS("Cereals", "cereals", false, 0.9393854,0.2),
	OILCROPS("Oilcrops", "oilcrops", false, 2.0640544,0.1),
	PULSES("Pulses", "pulses", false, 2.5886803,0.4),
	STARCHY_ROOTS("Starchy Roots", "starchyRoots", false, 0.4925546,0.3),
	MONOGASTRICS("Monogastrics", "monogastrics", true, 0.4680600, 1.0),
	RUMINANTS("Ruminants", "ruminants", true, 0.6135583, 1.0);

	private String faoName;
	private String gamsName;
	private boolean isAnimalProduct;
	private double energyPerTon;
	private double meatSubstitutionProportion;
	
	CommodityType (String faoName, String gamsName, boolean isAnimalProduct, double energyPerTon, double meatSubstitutionProportion) {
		this.faoName = faoName;
		this.gamsName = gamsName;
		this.isAnimalProduct = isAnimalProduct;
		this.energyPerTon = energyPerTon;
		this.meatSubstitutionProportion = meatSubstitutionProportion;
	}
	
	private static final Map<String, CommodityType> faoNameCache = new HashMap<String, CommodityType>();
    static {
        for (CommodityType c : values()) {
        	faoNameCache.put(c.getFaoName(), c);
       }
    }

	public static CommodityType getForFaoName(String faoName) {
		CommodityType commodity = faoNameCache.get(faoName);

		if (commodity == null) 
			throw new RuntimeException("Can't find CommodityType for faoName: " + faoName);
		
		return commodity;
	}
	
	public static Collection<CommodityType> getAllItems() {
		return faoNameCache.values();
	}

	public String getFaoName() {
		return faoName;
	}
	
	public String getGamsName() {
		return gamsName;
	}

	public boolean isAnimalProduct() {
		return isAnimalProduct;
	}
	
	public double getEnergyPerTon(){
		return energyPerTon;
	}
	
	public double getMeatSubstitutionProportion(){
		return meatSubstitutionProportion;
	}
	
	public double getSeedWasteRate() {
		// just waste rate for animal products
		return isAnimalProduct ? ModelConfig.SEED_AND_WASTE_FRACTION/2 : ModelConfig.SEED_AND_WASTE_FRACTION;
	}
}
